HPGL web resources — Chiplotle v0.2 documentation

### Navigation

- index
- modules |
- previous |
- Chiplotle »
- Chiplotle v0.2 documentation »

# HPGL web resources

## HPGL references

- http://local.wasp.uwa.edu.au/~pbourke/dataformats/hpgl/

## Tools

- hp2xx: an HPGL to x converter. Very handy for converting your HPGL files to other image formats. hp2xx in part of the GNU project, so in Linux simply use your package manager to install. (e.g., in Debian: `sudo apt-get install hp2xx`). For other operating systems you will need to download and compile from source.

    Note

    hp2xx is required for exporting and previewing in Chiplotle.

- pstoedit: a Post Script to HPGL converter.

- autotrace: transform your bitmaps into vector graphics.

- potrace: transform your bitmaps into vector graphics. Works a bit differently than `autotrace`.

### Navigation

- index
- modules |
- previous |
- Chiplotle »
- Chiplotle v0.2 documentation »